pub struct KernelWriter {
state: IrqMutexGuard<'static, KPrintState>,
buffer: [u8; 2048],
text_len: usize,
log_level: LogLevel,
log_flags: LogFlags,
}Expand description
Wrapper that holds the acquired Ringbuffer guard and a buffer in which [core::fmt::write]
calls get written, which then gets written to the ring buffer
Fields
state: IrqMutexGuard<'static, KPrintState>buffer: [u8; 2048]text_len: usizelog_level: LogLevellog_flags: LogFlagsImplementations
Sourceimpl KernelWriter
impl KernelWriter
Sourcepub fn lock(log_level: LogLevel, log_flags: LogFlags) -> Self
pub fn lock(log_level: LogLevel, log_flags: LogFlags) -> Self
Acquire the ringbuffer and return a KernelWriter holding the guard